@@ -1,6 +1,9 @@
 from typing import Dict
 
 class Component: 
+
+   
+
     def __init__(self, id: str, attributes: Dict) -> None:
         self.id = id
         self.attributes = attributes
@@ -9,13 +12,8 @@ class Component:
     def __create_styles(self, style_list: str):
         self.styles = {}
         if not style_list == None:
-            for style in style_list.split(";"):
-                styles = style.replace('\n','').split('=')
-                if '=' in style:
-                    self.styles[styles[0]] = styles[1].replace('"', '')
-                else:
-                    self.styles['style'] = styles[0]
-        
+            self.styles = style_list.split(";")[-1]
+            
     def get_styles(self):
         return self.styles
 
@@ -53,4 +51,8 @@ class Component:
         return self.styles.get('cvc-template-type')
 
     def get_template_name(self):
-        return self.styles.get('cvc-template-name')
\ No newline at end of file
+        return self.styles.get('cvc-template-name')
+
+
+
+  
\ No newline at end of file
